changeset 22720:ab4f30149aa0

(x-complement-fontset-spec): Typo fixed. (create-fontset-from-fontset-spec): Likewise. (create-fontset-from-ascii-font): Likewise.
author Kenichi Handa <handa@m17n.org>
date Thu, 09 Jul 1998 02:02:33 +0000
parents d6f6ac5a5df3
children d023df160219
files lisp/international/fontset.el
diffstat 1 files changed, 2 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/international/fontset.el	Thu Jul 09 02:02:33 1998 +0000
+++ b/lisp/international/fontset.el	Thu Jul 09 02:02:33 1998 +0000
@@ -317,7 +317,7 @@
 	    (register-alternate-fontnames fontname))))
       (setq charsets (cdr charsets)))
 
     ;; Be sure that ASCII font is avairable.
     (let ((slot (or (assq 'ascii fontlist) (assq 'ascii new-fontlist)))
 	  ascii-font)
       (if (setq ascii-font (condition-case nil
@@ -551,7 +551,7 @@
 
 Optional 1st arg RESOLVED-FONT is a resolved name of FONT.  If
 omitted, x-resolve-font-name is called to get the resolved name.  At
-this time, if FONT is not avairable, error is signaled.
+this time, if FONT is not available, error is signaled.
 
 Optional 2nd arg FONTSET-NAME is a string to be used in
 `<CHARSET_ENCODING>' fields of a new fontset name.  If it is omitted,
@@ -317,7 +317,7 @@
       (setq charsets (cdr charsets)))
 
-    ;; Be sure that ASCII font is avairable.
+    ;; Be sure that ASCII font is available.
     (let ((slot (or (assq 'ascii fontlist) (assq 'ascii new-fontlist)))
 	  ascii-font)